==> nextcloud-28.0.3.tgz: nextcloud/apps/twofactor_backupcodes/l10n/et_EE.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Sa lõid oma konto jaoks kaheastmelise autentimise varukoodid",
    "Second-factor backup codes" : "Kaheastmelise autentimise varukoodid",
    "Generate backup codes" : "Genereeri varukoodid",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Sa lülitasid sisse kaheastmelise autentimise, aga pole veel varukoode genereerinud. Neid on vaja kontole ligipääsemiseks, kui peaksid oma teise autentimisfaktori kaotama.",
    "Backup code" : "Varukood",
    "Use backup code" : "Kasuta varukoodi",
    "Two factor backup codes" : "Kaheastmelise autentimise varukoodid",
    "A two-factor auth backup codes provider" : "Kaheastmelise autentimise varukoodide pakkuja",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Varukoodid genereeritud. {used} koodi {total}-st on kasutatud.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Need on su varukoodid. Palun salvesta ja/või trüki need välja, sest rohkem sa neid vaadata ei saa.",
    "Save backup codes" : "Salvesta varukoodid",
    "Print backup codes" : "Trüki varukoodid",
    "Regenerate backup codes" : "Genereeri varukoodid uuesti",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Kui genereerid varukoodid uuesti, muudad vanad koodid automaatselt kehtetuks.",
    "An error occurred while generating your backup codes" : "Varukoodide genereerimisel tekkis tõrge",
    "{name} backup codes" : "{name} varukoodid",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Kasuta üht kaheastmelise autentimise seadistamisel salvestatud varukoodidest.",
    "Submit" : "Saada"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/et_EE.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Sa lõid oma konto jaoks kaheastmelise autentimise varukoodid",
    "Second-factor backup codes" : "Kaheastmelise autentimise varukoodid",
    "Generate backup codes" : "Genereeri varukoodid",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Sa lülitasid sisse kaheastmelise autentimise, aga pole veel varukoode genereerinud. Neid on vaja kontole ligipääsemiseks, kui peaksid oma teise autentimisfaktori kaotama.",
    "Backup code" : "Varukood",
    "Use backup code" : "Kasuta varukoodi",
    "Two factor backup codes" : "Kaheastmelise autentimise varukoodid",
    "A two-factor auth backup codes provider" : "Kaheastmelise autentimise varukoodide pakkuja",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Varukoodid genereeritud. {used} koodi {total}-st on kasutatud.",
    "Save backup codes" : "Salvesta varukoodid",
    "Print backup codes" : "Trüki varukoodid",
    "Regenerate backup codes" : "Genereeri varukoodid uuesti",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Kui genereerid varukoodid uuesti, muudad vanad koodid automaatselt kehtetuks.",
    "An error occurred while generating your backup codes" : "Varukoodide genereerimisel tekkis tõrge",
    "{name} backup codes" : "{name} varukoodid",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Kasuta üht kaheastmelise autentimise seadistamisel salvestatud varukoodidest.",
    "Submit" : "Saada",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Need on su varukoodid. Palun salvesta ja/või trüki need välja, sest rohkem sa neid vaadata ei saa."
},
"nplurals=2; plural=(n != 1);");
